@@ -22,15 +22,14 @@ certain handler:
 
 ```python
 class StackUnderTest(Stack):
-    def __init__(self, scope, id, *, functionProps=None, description=None, env=None, stackName=None, tags=None, synthesizer=None, terminationProtection=None, analyticsReporting=None):
-        super().__init__(scope, id, functionProps=functionProps, description=description, env=env, stackName=stackName, tags=tags, synthesizer=synthesizer, terminationProtection=terminationProtection, analyticsReporting=analyticsReporting)
+    def __init__(self, scope, id, *, architecture=None, description=None, env=None, stackName=None, tags=None, synthesizer=None, terminationProtection=None, analyticsReporting=None):
+        super().__init__(scope, id, architecture=architecture, description=description, env=env, stackName=stackName, tags=tags, synthesizer=synthesizer, terminationProtection=terminationProtection, analyticsReporting=analyticsReporting)
 
         lambda_.Function(self, "Handler",
             runtime=lambda_.Runtime.NODEJS_12_X,
             handler="index.handler",
             code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler")),
-            (SpreadAssignment ...props.functionProps
-              function_props)
+            architecture=architecture
         )
 ```
 
@@ -55,7 +54,8 @@ class StackUnderTest(Stack):
 app = App()
 
 stack = Stack(app, "stack")
-IntegTestCase(stack, "DifferentArchitectures",
+
+different_archs_case = IntegTestCase(stack, "DifferentArchitectures",
     stacks=[
         StackUnderTest(app, "Stack1",
             architecture=lambda_.Architecture.ARM_64
@@ -65,6 +65,13 @@ IntegTestCase(stack, "DifferentArchitectures",
         )
     ]
 )
+
+# There must be exactly one instance of TestCase per file
+IntegTest(app, "integ-test",
+
+    # Register as many test cases as you want here
+    test_cases=[different_archs_case]
+)
 ```
 
 This is all the instruction you need for the integration test runner to know
@@ -78,7 +85,7 @@ stack_under_test = Stack(app, "StackUnderTest")
 
 stack = Stack(app, "stack")
 
-IntegTestCase(stack, "CustomizedDeploymentWorkflow",
+test_case = IntegTestCase(stack, "CustomizedDeploymentWorkflow",
     stacks=[stack_under_test],
     diff_assets=True,
     stack_update_workflow=True,
@@ -96,6 +103,10 @@ IntegTestCase(stack, "CustomizedDeploymentWorkflow",
         )
     )
 )
+
+IntegTest(app, "integ-test",
+    test_cases=[test_case]
+)
 ```
 '''
 import abc
@@ -114,6 +125,90 @@ import aws_cdk.cloud_assembly_schema
 import aws_cdk.core
 
 
+class IntegTest(
+    aws_cdk.core.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/integ-tests.IntegTest",
+):
+    '''(experimental) A collection of test cases.
+
+    Each test case file should contain exactly one
+    instance of this class.
+
+    :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        class StackUnderTest(Stack):
+            def __init__(self, scope, id, *, architecture=None, description=None, env=None, stackName=None, tags=None, synthesizer=None, terminationProtection=None, analyticsReporting=None):
+                super().__init__(scope, id, architecture=architecture, description=description, env=env, stackName=stackName, tags=tags, synthesizer=synthesizer, terminationProtection=terminationProtection, analyticsReporting=analyticsReporting)
+        
+                lambda_.Function(self, "Handler",
+                    runtime=lambda_.Runtime.NODEJS_12_X,
+                    handler="index.handler",
+                    code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler")),
+                    architecture=architecture
+                )
+        
+        # Beginning of the test suite
+        app = App()
+        
+        stack = Stack(app, "stack")
+        
+        different_archs_case = IntegTestCase(stack, "DifferentArchitectures",
+            stacks=[
+                StackUnderTest(app, "Stack1",
+                    architecture=lambda_.Architecture.ARM_64
+                ),
+                StackUnderTest(app, "Stack2",
+                    architecture=lambda_.Architecture.X86_64
+                )
+            ]
+        )
+        
+        # There must be exactly one instance of TestCase per file
+        IntegTest(app, "integ-test",
+        
+            # Register as many test cases as you want here
+            test_cases=[different_archs_case]
+        )
+    '''
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: builtins.str,
+        *,
+        test_cases: typing.Sequence["IntegTestCase"],
+    ) -> None:
+        '''
+        :param scope: -
+        :param id: -
+        :param test_cases: (experimental) List of test cases that make up this test.
+
+        :stability: experimental
+        '''
+        props = IntegTestProps(test_cases=test_cases)
+
+        jsii.create(self.__class__, self, [scope, id, props])
+
+    @jsii.member(jsii_name="onPrepare")
+    def _on_prepare(self) -> None:
+        '''(experimental) Perform final modifications before synthesis.
+
+        This method can be implemented by derived constructs in order to perform
+        final changes before synthesis. prepare() will be called after child
+        constructs have been prepared.
+
+        This is an advanced framework feature. Only use this if you
+        understand the implications.
+
+        :stability: experimental
+        '''
+        return typing.cast(None, jsii.invoke(self, "onPrepare", []))
+
+
 class IntegTestCase(
     aws_cdk.core.Construct,
     metaclass=jsii.JSIIMeta,
@@ -144,7 +239,8 @@ class IntegTestCase(
         app = App()
         
         stack = Stack(app, "stack")
-        IntegTestCase(stack, "DifferentArchitectures",
+        
+        different_archs_case = IntegTestCase(stack, "DifferentArchitectures",
             stacks=[
                 StackUnderTest(app, "Stack1",
                     architecture=lambda_.Architecture.ARM_64
@@ -154,6 +250,13 @@ class IntegTestCase(
                 )
             ]
         )
+        
+        # There must be exactly one instance of TestCase per file
+        IntegTest(app, "integ-test",
+        
+            # Register as many test cases as you want here
+            test_cases=[different_archs_case]
+        )
     '''
 
     def __init__(
@@ -194,6 +297,18 @@ class IntegTestCase(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="manifest")
+    def manifest(self) -> aws_cdk.cloud_assembly_schema.IntegManifest:
+        '''(experimental) The integration test manifest for this test case.
+
+        Manifests are used
+        by the integration test runner.
+
+        :stability: experimental
+        '''
+        return typing.cast(aws_cdk.cloud_assembly_schema.IntegManifest, jsii.get(self, "manifest"))
+
 
 @jsii.data_type(
     jsii_type="@aws-cdk/integ-tests.IntegTestCaseProps",
@@ -250,7 +365,8 @@ class IntegTestCaseProps(aws_cdk.cloud_assembly_schema.TestOptions):
             app = App()
             
             stack = Stack(app, "stack")
-            IntegTestCase(stack, "DifferentArchitectures",
+            
+            different_archs_case = IntegTestCase(stack, "DifferentArchitectures",
                 stacks=[
                     StackUnderTest(app, "Stack1",
                         architecture=lambda_.Architecture.ARM_64
@@ -260,6 +376,13 @@ class IntegTestCaseProps(aws_cdk.cloud_assembly_schema.TestOptions):
                     )
                 ]
             )
+            
+            # There must be exactly one instance of TestCase per file
+            IntegTest(app, "integ-test",
+            
+                # Register as many test cases as you want here
+                test_cases=[different_archs_case]
+            )
         '''
         if isinstance(cdk_command_options, dict):
             cdk_command_options = aws_cdk.cloud_assembly_schema.CdkCommands(**cdk_command_options)
@@ -371,9 +494,87 @@ class IntegTestCaseProps(aws_cdk.cloud_assembly_schema.TestOptions):
         )
 
 
+@jsii.data_type(
+    jsii_type="@aws-cdk/integ-tests.IntegTestProps",
+    jsii_struct_bases=[],
+    name_mapping={"test_cases": "testCases"},
+)
+class IntegTestProps:
+    def __init__(self, *, test_cases: typing.Sequence[IntegTestCase]) -> None:
+        '''(experimental) Integration test properties.
+
+        :param test_cases: (experimental) List of test cases that make up this test.
+
+        :stability: experimental
+        :exampleMetadata: infused
+
+        Example::
+
+            class StackUnderTest(Stack):
+                def __init__(self, scope, id, *, architecture=None, description=None, env=None, stackName=None, tags=None, synthesizer=None, terminationProtection=None, analyticsReporting=None):
+                    super().__init__(scope, id, architecture=architecture, description=description, env=env, stackName=stackName, tags=tags, synthesizer=synthesizer, terminationProtection=terminationProtection, analyticsReporting=analyticsReporting)
+            
+                    lambda_.Function(self, "Handler",
+                        runtime=lambda_.Runtime.NODEJS_12_X,
+                        handler="index.handler",
+                        code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler")),
+                        architecture=architecture
+                    )
+            
+            # Beginning of the test suite
+            app = App()
+            
+            stack = Stack(app, "stack")
+            
+            different_archs_case = IntegTestCase(stack, "DifferentArchitectures",
+                stacks=[
+                    StackUnderTest(app, "Stack1",
+                        architecture=lambda_.Architecture.ARM_64
+                    ),
+                    StackUnderTest(app, "Stack2",
+                        architecture=lambda_.Architecture.X86_64
+                    )
+                ]
+            )
+            
+            # There must be exactly one instance of TestCase per file
+            IntegTest(app, "integ-test",
+            
+                # Register as many test cases as you want here
+                test_cases=[different_archs_case]
+            )
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "test_cases": test_cases,
+        }
+
+    @builtins.property
+    def test_cases(self) -> typing.List[IntegTestCase]:
+        '''(experimental) List of test cases that make up this test.
+
+        :stability: experimental
+        '''
+        result = self._values.get("test_cases")
+        assert result is not None, "Required property 'test_cases' is missing"
+        return typing.cast(typing.List[IntegTestCase], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "IntegTestProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 __all__ = [
+    "IntegTest",
     "IntegTestCase",
     "IntegTestCaseProps",
+    "IntegTestProps",
 ]
 
 publication.publish()
